import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';
// improting csv data for GitHub Gist
const csvUrl = 'https://gist.githubusercontent.com/areepatw96/3d3788cca2fd223a220754b519e5b724/raw/327f0281173acc2aeb3718d3d95c55b4c003bebf/iris.csv';
// storing data in each variable
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};
// assigning width and height
const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;      
const group = (d) => d.species;
// genarting plot from the values above
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  
  const x = xValue((d) => d.petal_width);
        
  const y = yValue((d) => d.sepal_length);
  

  const color = d3.scaleOrdinal()
    .domain(["setosa", "versicolor", "virginica" ])
    .range([ "#10EF01 ", "#6F46CA", "#EC2363 "]);
  // coloring the SVG marks in the scatter plot

  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          color: color(group(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  

  // plotting the scatter plot 
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 130,
      bottom: 40,
      left: 50,
    })
    .radius(5);
  // creating legends
    const legend = svg.selectAll('legend')
      .data(color.domain())
      .enter().append('g')
      .attr('class', 'legend')
      .attr('transform', function(d,i){ return 'translate(0,' + i * 20 + ')'; });
	// assigning legend shape
    legend.append('rect')
      .attr('x', width-20)
      .attr('width', 18)
      .attr('height', 18)
      .style('fill', color);
	//assigning legend names/titles
    legend.append('text')
    .attr('x', width - 26)
    .attr('y', 9)
    .attr('dy', '.35em')
    .style('text-anchor', 'end')
    .attr("font-family", "Arial, Helvetica, sans-serif")
    .text(function(d){ return d; });
		//drawing circles and styling 
		svg.selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
  
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();



